@@ -16,6 +16,5 @@ void C_sens_uno( double *sens, double *surv_time, double *status, double *thres,
 void C_auc_uno( double *auc, double *i_auc, double *sens, double *spec, double *surv_time,
 			 double *status, double *thres, double *t, double *marker, double *new_surv_t,
 			 double *new_event, int *n_th, int *n_t, int *n_new_data, int *n_surv);
-void C_int_auc( double *i_auc, double *auc, double *time, double *S, 
-			 double *tmax, int *n_S, int *wChoice, int *maxI, double *maxS, int *Con_Inc);
-
+void C_int_auc(double *auc, double *time, double *S, 
+			 double *tmax, int *n_S, int *maxI, double *maxS, int *Con_Inc, double *i_auc);
