@@ -38,7 +38,7 @@ void C_GHCI(double *lp, int *n_lp, double *ans){
 
 
 /* Calculation of censoring weights Cox-Model*/
-void cens_weights(double *times, int *n_times, double *stime, double *event, int *n_stime,
+void C_cens_weights(double *times, int *n_times, double *stime, double *event, int *n_stime,
 				  double *stime_new, double *event_new, int *n_stime_new, double *weights)
 {
 	int i, j;
@@ -106,7 +106,7 @@ SEXP C_predError(SEXP TIME, SEXP EVENT, SEXP N_TIME,
 		event[i] = 1. - REAL(EVENT)[i];
 	}
 	
-	cens_weights(REAL(TH_TIME), INTEGER(N_TH_TIME), REAL(TIME), event, INTEGER(N_TIME),
+	C_cens_weights(REAL(TH_TIME), INTEGER(N_TH_TIME), REAL(TIME), event, INTEGER(N_TIME),
 				 REAL(TIME_NEW), REAL(EVENT_NEW), INTEGER(N_TIME_NEW), weights);
 	Free(event);
 	
